@@ -1,11 +1,3 @@
-// Copyright (c) 2018-2021 Stefan Lankes, RWTH Aachen University
-//               2018 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 mod bootinfo;
 pub mod irq;
 pub mod pci;
@@ -71,6 +63,10 @@ pub fn get_tls_memsz() -> usize {
 	0
 }
 
+pub fn get_tls_align() -> usize {
+	0
+}
+
 /// Whether HermitCore is running under the "uhyve" hypervisor.
 pub fn is_uhyve() -> bool {
 	unsafe { core::ptr::read_volatile(&BOOT_INFO.uhyve) != 0 }
