@@ -1,11 +1,3 @@
-// Copyright (c) 2018-2020 Stefan Lankes, RWTH Aachen University
-//               2018 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 //! Architecture dependent interface to initialize a task
 
 use crate::arch::aarch64::kernel::percore::*;
@@ -215,22 +207,17 @@ pub struct TaskTLS {
 }
 
 impl TaskTLS {
-	pub fn new(tls_size: usize) -> Self {
+	fn from_environment() -> Self {
 		Self {
 			address: VirtAddr::zero(),
 		}
 	}
-
-	#[inline]
-	pub fn address(&self) -> VirtAddr {
-		self.address
-	}
 }
 
 impl Drop for TaskTLS {
 	fn drop(&mut self) {
 		/*debug!(
-				"Deallocate TLS at 0x{:x} (layout {:?})",
+				"Deallocate TLS at {:#x} (layout {:?})",
 				self.address, self.layout,
 		);
 
@@ -242,7 +229,7 @@ impl Drop for TaskTLS {
 
 impl Clone for TaskTLS {
 	fn clone(&self) -> Self {
-		TaskTLS::new(environment::get_tls_memsz())
+		TaskTLS::from_environment()
 	}
 }
 
@@ -257,10 +244,10 @@ extern "C" fn task_entry(func: extern "C" fn(usize), arg: usize) {
 		// Yes, it does, so we have to allocate TLS memory.
 		// Allocate enough space for the given size and one more variable of type usize, which holds the tls_pointer.
 		let tls_allocation_size = tls_size + mem::size_of::<usize>();
-		let tls = TaskTLS::new(tls_allocation_size);
+		let tls = TaskTLS::from_environment();
 
 		// The tls_pointer is the address to the end of the TLS area requested by the task.
-		let tls_pointer = tls.address() + tls_size;
+		let tls_pointer = tls.address + tls_size;
 
 		// TODO: Implement AArch64 TLS
 
@@ -269,7 +256,7 @@ extern "C" fn task_entry(func: extern "C" fn(usize), arg: usize) {
 		debug!(
 			"Set up TLS for task {} at address {:#X}",
 			current_task_borrowed.id,
-			tls.address()
+			tls.address
 		);
 		current_task_borrowed.tls = Some(tls);
 	}*/
