@@ -1,15 +1,8 @@
-// Copyright (c) 2017 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 use crate::arch;
 #[cfg(feature = "acpi")]
 use crate::arch::x86_64::kernel::acpi;
 use crate::arch::x86_64::kernel::irq::IrqStatistics;
-#[cfg(all(target_os = "hermit", feature = "smp"))]
+#[cfg(all(any(target_os = "none", target_os = "hermit"), feature = "smp"))]
 use crate::arch::x86_64::kernel::smp_boot_code::SMP_BOOT_CODE;
 use crate::arch::x86_64::kernel::IRQ_COUNTERS;
 use crate::arch::x86_64::mm::paging::{BasePageSize, PageSize, PageTableEntryFlags};
@@ -27,9 +20,8 @@ use crate::x86::msr::*;
 use alloc::boxed::Box;
 use alloc::vec::Vec;
 use arch::x86_64::kernel::{idt, irq, percore::*, processor, BOOT_INFO};
+#[cfg(feature = "pci")]
 use core::arch::x86_64::_mm_mfence;
-#[cfg(feature = "smp")]
-use core::convert::TryInto;
 use core::hint::spin_loop;
 #[cfg(feature = "smp")]
 use core::ptr;
@@ -267,20 +259,40 @@ fn detect_from_acpi() -> Result<PhysAddr, ()> {
 	Ok(PhysAddr(madt_header.local_apic_address.into()))
 }
 
+fn default_apic() -> PhysAddr {
+	warn!("Try to use default APIC address");
+
+	let default_address = PhysAddr(0xFEC0_0000);
+
+	unsafe {
+		IOAPIC_ADDRESS = virtualmem::allocate(BasePageSize::SIZE).unwrap();
+		debug!(
+			"Mapping IOAPIC at {:#X} to virtual address {:#X}",
+			default_address, IOAPIC_ADDRESS
+		);
+
+		let mut flags = PageTableEntryFlags::empty();
+		flags.device().writable().execute_disable();
+		paging::map::<BasePageSize>(IOAPIC_ADDRESS, default_address, 1, flags);
+	}
+
+	PhysAddr(0xFEE0_0000)
+}
+
 fn detect_from_uhyve() -> Result<PhysAddr, ()> {
 	if environment::is_uhyve() {
-		let defaullt_address = PhysAddr(0xFEC0_0000);
+		let default_address = PhysAddr(0xFEC0_0000);
 
 		unsafe {
 			IOAPIC_ADDRESS = virtualmem::allocate(BasePageSize::SIZE).unwrap();
 			debug!(
 				"Mapping IOAPIC at {:#X} to virtual address {:#X}",
-				defaullt_address, IOAPIC_ADDRESS
+				default_address, IOAPIC_ADDRESS
 			);
 
 			let mut flags = PageTableEntryFlags::empty();
 			flags.device().writable().execute_disable();
-			paging::map::<BasePageSize>(IOAPIC_ADDRESS, defaullt_address, 1, flags);
+			paging::map::<BasePageSize>(IOAPIC_ADDRESS, default_address, 1, flags);
 		}
 
 		return Ok(PhysAddr(0xFEE0_0000));
@@ -309,8 +321,8 @@ pub fn init() {
 
 	// Detect CPUs and APICs.
 	let local_apic_physical_address = detect_from_uhyve()
-		.or_else(|_e| detect_from_acpi())
-		.expect("HermitCore requires an APIC system");
+		.or_else(|_| detect_from_acpi())
+		.unwrap_or_else(|_| default_apic());
 
 	// Initialize x2APIC or xAPIC, depending on what's available.
 	init_x2apic();
@@ -541,7 +553,7 @@ pub fn init_next_processor_variables(core_id: CoreId) {
 		);
 
 		trace!(
-			"Initialize per core data at 0x{:x} (size {} bytes)",
+			"Initialize per core data at {:#x} (size {} bytes)",
 			core::ptr::read_volatile(&(*BOOT_INFO).current_percore_address),
 			mem::size_of::<PerCoreVariables>()
 		);
@@ -556,7 +568,7 @@ extern "C" {
 /// This algorithm is derived from Intel MultiProcessor Specification 1.4, B.4, but testing has shown
 /// that a second STARTUP IPI and setting the BIOS Reset Vector are no longer necessary.
 /// This is partly confirmed by https://wiki.osdev.org/Symmetric_Multiprocessing
-#[cfg(all(target_os = "hermit", feature = "smp"))]
+#[cfg(all(any(target_os = "none", target_os = "hermit"), feature = "smp"))]
 pub fn boot_application_processors() {
 	// We shouldn't have any problems fitting the boot code into a single page, but let's better be sure.
 	assert!(
@@ -592,7 +604,7 @@ pub fn boot_application_processors() {
 			cr3().try_into().unwrap();
 		// Set entry point
 		debug!(
-			"Set entry point for application processor to 0x{:x}",
+			"Set entry point for application processor to {:#x}",
 			_start as usize
 		);
 		*((SMP_BOOT_CODE_ADDRESS + SMP_BOOT_CODE_OFFSET_ENTRY).as_mut_ptr()) = _start as usize;
@@ -679,6 +691,7 @@ pub fn ipi_tlb_flush() {
 }
 
 /// Send an inter-processor interrupt to wake up a CPU Core that is in a HALT state.
+#[allow(unused_variables)]
 pub fn wakeup_core(core_id_to_wakeup: CoreId) {
 	#[cfg(feature = "smp")]
 	if core_id_to_wakeup != core_id() {
