@@ -1,11 +1,3 @@
-// Copyright (c) 2017 Stefan Lankes, RWTH Aachen University
-//                    Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 use crate::arch::x86_64::kernel::gdt;
 use crate::x86::bits64::paging::VAddr;
 use crate::x86::dtables::{self, DescriptorTablePointer};
@@ -122,7 +114,7 @@ pub fn install() {
 		let is_init = IDT_INIT.swap(true, Ordering::SeqCst);
 
 		if !is_init {
-			debug!("IDT address: 0x{:x}", &IDT.entries as *const _ as usize);
+			debug!("IDT address: {:#x}", &IDT.entries as *const _ as usize);
 
 			// TODO: As soon as https://github.com/rust-lang/rust/issues/44580 is implemented, it should be possible to
 			// implement "new" as "const fn" and do this call already in the initialization of IDTP.
