@@ -1,11 +1,3 @@
-// Copyright (c) 2017 Stefan Lankes, RWTH Aachen University
-//                    Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 #![allow(dead_code)]
 
 #[cfg(feature = "acpi")]
@@ -19,9 +11,9 @@ use core::arch::x86_64::{
 	__rdtscp, _fxrstor, _fxsave, _mm_lfence, _rdrand32_step, _rdrand64_step, _rdtsc, _xrstor,
 	_xsave,
 };
-use core::convert::TryInto;
 use core::hint::spin_loop;
 use core::{fmt, u32};
+use qemu_exit::QEMUExit;
 use x86::bits64::segmentation;
 
 const IA32_MISC_ENABLE_ENHANCED_SPEEDSTEP: u64 = 1 << 16;
@@ -345,14 +337,14 @@ impl CpuFrequency {
 		pic::eoi(pit::PIT_INTERRUPT_NUMBER);
 	}
 
-	#[cfg(not(target_os = "hermit"))]
+	#[cfg(not(any(target_os = "none", target_os = "hermit")))]
 	fn measure_frequency(&mut self) -> Result<(), ()> {
 		// return just Ok because the real implementation must run in ring 0
 		self.source = CpuFrequencySources::Measurement;
 		Ok(())
 	}
 
-	#[cfg(target_os = "hermit")]
+	#[cfg(any(target_os = "none", target_os = "hermit"))]
 	fn measure_frequency(&mut self) -> Result<(), ()> {
 		// The PIC is not initialized for uhyve, so we cannot measure anything.
 		if environment::is_uhyve() {
@@ -424,7 +416,7 @@ impl CpuFrequency {
 			.or_else(|_e| self.detect_from_cpuid_tsc_info(&cpuid))
 			.or_else(|_e| self.detect_from_cpuid_hypervisor_info(&cpuid))
 			.or_else(|_e| self.detect_from_hypervisor())
-			//.or_else(|_e| self.detect_from_cmdline())
+			.or_else(|_e| self.detect_from_cmdline())
 			.or_else(|_e| self.detect_from_cpuid_brand_string(&cpuid))
 			.or_else(|_e| self.measure_frequency())
 			.expect("Could not determine the processor frequency");
@@ -763,7 +755,7 @@ pub fn configure() {
 	// Prevent writes to read-only pages in Ring 0.
 	cr0.insert(Cr0::CR0_WRITE_PROTECT);
 
-	debug!("Set CR0 to 0x{:x}", cr0);
+	debug!("Set CR0 to {:#x}", cr0);
 	unsafe {
 		cr0_write(cr0);
 	}
@@ -803,7 +795,7 @@ pub fn configure() {
 		crate::__sys_shutdown(1);
 	}
 
-	debug!("Set CR4 to 0x{:x}", cr4);
+	debug!("Set CR4 to {:#x}", cr4);
 	unsafe {
 		cr4_write(cr4);
 	}
@@ -821,7 +813,7 @@ pub fn configure() {
 			xcr0.insert(Xcr0::XCR0_AVX_STATE);
 		}
 
-		debug!("Set XCR0 to 0x{:x}", xcr0);
+		debug!("Set XCR0 to {:#x}", xcr0);
 		unsafe {
 			xcr0_write(xcr0);
 		}
@@ -873,7 +865,7 @@ pub fn print_information() {
 	infofooter!();
 }
 
-/*#[cfg(not(target_os = "hermit"))]
+/*#[cfg(not(any(target_os = "none", target_os = "hermit")))]
 #[test]
 fn print_cpu_information() {
 	::logging::init();
@@ -965,9 +957,9 @@ pub fn shutdown() -> ! {
 	#[cfg(feature = "acpi")]
 	acpi::poweroff();
 
-	loop {
-		halt();
-	}
+	// assume that we running on Qemu
+	let exit_handler = qemu_exit::X86::new(0xf4, 3);
+	exit_handler.exit_success()
 }
 
 pub fn get_timer_ticks() -> u64 {
