@@ -1,11 +1,3 @@
-// Copyright (c) 2017 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
-use core::convert::TryInto;
 use core::marker::PhantomData;
 use core::mem;
 use core::ptr;
@@ -744,7 +736,7 @@ pub fn init_page_tables() {
 		let pml4 = controlregs::cr3();
 		let pde = pml4 + 2 * BasePageSize::SIZE as u64;
 
-		debug!("Found PML4 at 0x{:x}", pml4);
+		debug!("Found PML4 at {:#x}", pml4);
 
 		// make sure that only the required areas are mapped
 		let start = pde
@@ -763,7 +755,7 @@ pub fn init_page_tables() {
 		// Identity-map the supplied Multiboot information and command line.
 		let mb_info = get_mbinfo();
 		if !mb_info.is_zero() {
-			info!("Found Multiboot info at 0x{:x}", mb_info);
+			info!("Found Multiboot info at {:#x}", mb_info);
 			identity_map(PhysAddr(mb_info.as_u64()), PhysAddr(mb_info.as_u64()));
 
 			// Map the "Memory Map" information too.
@@ -780,7 +772,7 @@ pub fn init_page_tables() {
 		let cmdsize = environment::get_cmdsize();
 		if cmdsize > 0 {
 			let cmdline = environment::get_cmdline();
-			info!("Found cmdline at 0x{:x} (size {})", cmdline, cmdsize);
+			info!("Found cmdline at {:#x} (size {})", cmdline, cmdsize);
 			identity_map(
 				PhysAddr(cmdline.as_u64()),
 				PhysAddr(cmdline.as_u64()) + cmdsize - 1u64,
