@@ -1,12 +1,5 @@
-// Copyright (c) 2017 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
+use core::alloc::AllocError;
 use core::sync::atomic::{AtomicUsize, Ordering};
-use core::{alloc::AllocError, convert::TryInto};
 use multiboot::information::{MemoryType, Multiboot};
 
 use crate::arch::x86_64::kernel::{get_limit, get_mbinfo};
@@ -166,6 +159,29 @@ pub fn deallocate(physical_address: PhysAddr, size: usize) {
 		.deallocate(physical_address.as_usize(), size);
 }
 
+pub fn reserve(physical_address: PhysAddr, size: usize) {
+	assert_eq!(
+		physical_address % BasePageSize::SIZE,
+		0,
+		"Physical address {:#X} is not a multiple of {:#X}",
+		physical_address,
+		BasePageSize::SIZE
+	);
+	assert!(size > 0);
+	assert_eq!(
+		size % BasePageSize::SIZE,
+		0,
+		"Size {:#X} is not a multiple of {:#X}",
+		size,
+		BasePageSize::SIZE
+	);
+
+	// we are able to ignore errors because it could be already reserved
+	let _ = PHYSICAL_FREE_LIST
+		.lock()
+		.reserve(physical_address.as_usize(), size);
+}
+
 pub fn print_information() {
 	PHYSICAL_FREE_LIST
 		.lock()
