@@ -1,11 +1,3 @@
-// Copyright (c) 2019 Stefan Lankes, RWTH Aachen University
-//               2020 Frederik Schulz, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-//
 //! A module containing hermit-rs driver, hermit-rs driver trait and driver specific errors.
 //!
 //! The module contains ...
@@ -13,17 +5,18 @@
 // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 // UNCOMMENTED FOR CORRECT USE STATEMENT; IS THIS CORRECT?
 // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
+#[cfg(not(target_arch = "aarch64"))]
 pub mod net;
 
-#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
+#[cfg(not(target_arch = "aarch64"))]
 pub mod virtio;
 
 /// A common error module for drivers.
 /// [DriverError](enums.drivererror.html) values will be
 /// passed on to higher layers.
-#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
+#[cfg(not(target_arch = "aarch64"))]
 pub mod error {
+	#[cfg(feature = "pci")]
 	use crate::drivers::net::rtl8139::RTL8139Error;
 	use crate::drivers::virtio::error::VirtioError;
 	use core::fmt;
@@ -31,6 +24,7 @@ pub mod error {
 	#[derive(Debug)]
 	pub enum DriverError {
 		InitVirtioDevFail(VirtioError),
+		#[cfg(feature = "pci")]
 		InitRTL8139DevFail(RTL8139Error),
 	}
 
@@ -40,6 +34,7 @@ pub mod error {
 		}
 	}
 
+	#[cfg(feature = "pci")]
 	impl From<RTL8139Error> for DriverError {
 		fn from(err: RTL8139Error) -> Self {
 			DriverError::InitRTL8139DevFail(err)
@@ -52,6 +47,7 @@ pub mod error {
 				DriverError::InitVirtioDevFail(ref err) => {
 					write!(f, "Virtio driver failed: {:?}", err)
 				}
+				#[cfg(feature = "pci")]
 				DriverError::InitRTL8139DevFail(ref err) => {
 					write!(f, "RTL8139 driver failed: {:?}", err)
 				}
