@@ -1,15 +1,7 @@
-// Copyright (c) 2019-2021 Stefan Lankes, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 // The driver based on the online manual http://www.lowlevel.eu/wiki/RTL8139
 
 #![allow(dead_code)]
 
-use core::convert::TryInto;
 use core::mem;
 
 use crate::arch::kernel::irq::*;
@@ -241,6 +233,10 @@ impl NetworkInterface for RTL8139Driver {
 		}
 	}
 
+	fn free_tx_buffer(&self, _token: usize) {
+		// get_tx_buffer did not allocate
+	}
+
 	fn send_tx_buffer(&mut self, id: usize, len: usize) -> Result<(), ()> {
 		// send the packet
 		unsafe {
@@ -290,7 +286,7 @@ impl NetworkInterface for RTL8139Driver {
 				))
 			} else {
 				error!(
-					"RTL8192: invalid header 0x{:x}, rx_pos {}\n",
+					"RTL8192: invalid header {:#x}, rx_pos {}\n",
 					header, self.rxpos
 				);
 
@@ -419,7 +415,7 @@ pub fn init_device(adapter: &pci::PciAdapter) -> Result<RTL8139Driver, DriverErr
 		.unwrap();
 
 	debug!(
-		"Found RTL8139 at iobase 0x{:x} (irq {})",
+		"Found RTL8139 at iobase {:#x} (irq {})",
 		iobase, adapter.irq
 	);
 
@@ -507,7 +503,7 @@ pub fn init_device(adapter: &pci::PciAdapter) -> Result<RTL8139Driver, DriverErr
 	}
 
 	debug!(
-		"Allocate TxBuffer at 0x{:x} and RxBuffer at 0x{:x}",
+		"Allocate TxBuffer at {:#x} and RxBuffer at {:#x}",
 		txbuffer, rxbuffer
 	);
 
@@ -563,7 +559,7 @@ pub fn init_device(adapter: &pci::PciAdapter) -> Result<RTL8139Driver, DriverErr
 		outb(iobase + CR, CR_TE | CR_RE); // Sets the RE and TE bits high
 
 		info!(
-			"RTL8139: CR = 0x{:x}, ISR = 0x{:x}, speed = {} mbps",
+			"RTL8139: CR = {:#x}, ISR = {:#x}, speed = {} mbps",
 			inb(iobase + CR),
 			inw(iobase + ISR),
 			speed
