@@ -1,11 +1,3 @@
-// Copyright (c) 2020 Thomas Lambertz, RWTH Aachen University
-//               2020 Frederik Schulz, RWTH Aachen Univerity
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 //! A module containing all virtio specific pci functionality
 //!
 //! The module contains ...
@@ -17,7 +9,6 @@ use crate::arch::kernel::pci::{PciAdapter, PciDriver};
 use crate::arch::mm::PhysAddr;
 use crate::synch::spinlock::SpinlockIrqSave;
 use alloc::vec::Vec;
-use core::convert::TryInto;
 use core::mem;
 use core::result::Result;
 
@@ -520,7 +511,7 @@ impl ComCfg {
 	///
 	/// After this call, the device is "live"!
 	pub fn drv_ok(&mut self) {
-		self.com_cfg.device_status |= u8::from(device::Status::DRIVER_OK)
+		self.com_cfg.device_status |= u8::from(device::Status::DRIVER_OK);
 	}
 
 	/// Returns the features offered by the device. Coded in a 64bit value.
@@ -624,7 +615,6 @@ impl ComCfgRaw {
 
 /// Notification Structure to handle virtqueue notification settings.
 /// See Virtio specification v1.1 - 4.1.4.4
-//
 pub struct NotifCfg {
 	/// Start addr, from where the notification addresses for the virtqueues are computed
 	base_addr: VirtMemAddr,
@@ -762,6 +752,10 @@ impl IsrStatus {
 	pub fn is_cfg_change(&self) -> bool {
 		self.isr_stat.flags & 1 << 1 == 1 << 1
 	}
+
+	pub fn acknowledge(&mut self) {
+		// nothing to do
+	}
 }
 
 /// ISR status structure of Virtio PCI devices.
@@ -1238,7 +1232,7 @@ pub fn init_device(adapter: &PciAdapter) -> Result<VirtioDriver, DriverError> {
 		| DevId::VIRTIO_TRANS_DEV_ID_ENTROPY
 		| DevId::VIRTIO_TRANS_DEV_ID_9P => {
 			warn!(
-				"Legacy/transitional Virtio device, with id: 0x{:x} is NOT supported, skipping!",
+				"Legacy/transitional Virtio device, with id: {:#x} is NOT supported, skipping!",
 				adapter.device_id
 			);
 
@@ -1278,7 +1272,7 @@ pub fn init_device(adapter: &PciAdapter) -> Result<VirtioDriver, DriverError> {
 		}
 		_ => {
 			warn!(
-				"Virtio device with id: 0x{:x} is NOT supported, skipping!",
+				"Virtio device with id: {:#x} is NOT supported, skipping!",
 				adapter.device_id
 			);
 
