@@ -1,10 +1,3 @@
-// Copyright (c) 2020 Frederik Schulz, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 //! This module contains Virtio's virtqueue.
 //!
 //! The virtqueue is available in two forms.
@@ -27,6 +20,9 @@ use self::error::{BufferError, VirtqError};
 use self::packed::PackedVq;
 use self::split::SplitVq;
 
+#[cfg(not(feature = "pci"))]
+use super::transport::mmio::{ComCfg, NotifCfg};
+#[cfg(feature = "pci")]
 use super::transport::pci::{ComCfg, NotifCfg};
 use alloc::boxed::Box;
 use alloc::collections::VecDeque;
