@@ -1,16 +1,12 @@
-// Copyright (c) 2020 Frederik Schulz, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 //! This module contains Virtio's packed virtqueue.
 //! See Virito specification v1.1. - 2.7
 #![allow(dead_code)]
 
 use self::error::VqPackedError;
 use super::super::features::Features;
+#[cfg(not(feature = "pci"))]
+use super::super::transport::mmio::{ComCfg, NotifCfg, NotifCtrl};
+#[cfg(feature = "pci")]
 use super::super::transport::pci::{ComCfg, NotifCfg, NotifCtrl};
 use super::error::VirtqError;
 use super::{
@@ -23,7 +19,6 @@ use alloc::boxed::Box;
 use alloc::collections::VecDeque;
 use alloc::rc::Rc;
 use alloc::vec::Vec;
-use core::convert::TryFrom;
 use core::sync::atomic::{fence, Ordering};
 use core::{cell::RefCell, ptr};
 
