@@ -1,24 +1,17 @@
-// Copyright (c) 2018 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 //! Determining and providing information about the environment (unikernel
 //! vs. multi-kernel, hypervisor, etc.) as well as central parsing of the
 //! command-line parameters.
 
 #[cfg(target_arch = "x86_64")]
 pub use crate::arch::x86_64::kernel::{
-	get_base_address, get_cmdline, get_cmdsize, get_image_size, get_tls_filesz, get_tls_memsz,
-	get_tls_start, is_single_kernel, is_uhyve,
+	get_base_address, get_cmdline, get_cmdsize, get_image_size, get_tls_align, get_tls_filesz,
+	get_tls_memsz, get_tls_start, is_single_kernel, is_uhyve,
 };
 
 #[cfg(target_arch = "aarch64")]
 pub use crate::arch::aarch64::kernel::{
-	get_base_address, get_cmdline, get_cmdsize, get_image_size, get_tls_filesz, get_tls_memsz,
-	get_tls_start, is_single_kernel, is_uhyve,
+	get_base_address, get_cmdline, get_cmdsize, get_image_size, get_tls_align, get_tls_filesz,
+	get_tls_memsz, get_tls_start, is_single_kernel, is_uhyve,
 };
 
 use crate::util;
