@@ -1,11 +1,3 @@
-// Copyright (c) 2017 Stefan Lankes, RWTH Aachen University
-//                    Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 /*
  * First version is derived and adapted for HermitCore from
  * Philipp Oppermann's excellent series of blog posts (http://blog.phil-opp.com/)
@@ -19,6 +11,8 @@
 #![feature(abi_x86_interrupt)]
 #![feature(allocator_api)]
 #![feature(asm)]
+#![feature(asm_const)]
+#![feature(asm_sym)]
 #![feature(const_btree_new)]
 #![feature(const_fn_trait_bound)]
 #![feature(const_mut_refs)]
@@ -27,6 +21,7 @@
 #![feature(linkage)]
 #![feature(linked_list_cursors)]
 #![feature(naked_functions)]
+#![feature(new_uninit)]
 #![feature(panic_info_message)]
 #![feature(specialization)]
 #![feature(nonnull_slice_from_raw_parts)]
@@ -37,13 +32,19 @@
 #![feature(llvm_asm)]
 #![feature(global_asm)]
 #![no_std]
-#![cfg_attr(target_os = "hermit", feature(custom_test_frameworks))]
-#![cfg_attr(target_os = "hermit", cfg_attr(test, test_runner(crate::test_runner)))]
 #![cfg_attr(
-	target_os = "hermit",
+	any(target_os = "none", target_os = "hermit"),
+	feature(custom_test_frameworks)
+)]
+#![cfg_attr(
+	any(target_os = "none", target_os = "hermit"),
+	cfg_attr(test, test_runner(crate::test_runner))
+)]
+#![cfg_attr(
+	any(target_os = "none", target_os = "hermit"),
 	cfg_attr(test, reexport_test_harness_main = "test_main")
 )]
-#![cfg_attr(target_os = "hermit", cfg_attr(test, no_main))]
+#![cfg_attr(any(target_os = "none", target_os = "hermit"), cfg_attr(test, no_main))]
 
 // EXTERNAL CRATES
 #[macro_use]
@@ -54,7 +55,7 @@ extern crate bitflags;
 extern crate log;
 #[macro_use]
 extern crate num_derive;
-#[cfg(not(target_os = "hermit"))]
+#[cfg(not(any(target_os = "none", target_os = "hermit")))]
 #[macro_use]
 extern crate std;
 #[cfg(target_arch = "aarch64")]
@@ -92,9 +93,10 @@ mod console;
 mod drivers;
 pub mod environment;
 mod errno;
+mod ffi;
 mod kernel_message_buffer;
 mod mm;
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 mod runtime_glue;
 mod scheduler;
 mod synch;
@@ -108,7 +110,7 @@ pub fn _print(args: ::core::fmt::Arguments<'_>) {
 }
 
 #[cfg(test)]
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 #[no_mangle]
 extern "C" fn runtime_entry(_argc: i32, _argv: *const *const u8, _env: *const *const u8) -> ! {
 	println!("Executing hermit unittests. Any arguments are dropped");
@@ -126,14 +128,14 @@ pub fn test_runner(tests: &[&dyn Fn()]) {
 	sys_exit(0);
 }
 
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 #[test_case]
 fn trivial_test() {
 	println!("Test test test");
 	panic!("Test called");
 }
 
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 #[global_allocator]
 static ALLOCATOR: LockedHeap = LockedHeap::empty();
 
@@ -143,12 +145,12 @@ static ALLOCATOR: LockedHeap = LockedHeap::empty();
 /// Returning a null pointer indicates that either memory is exhausted or
 /// `size` and `align` do not meet this allocator's size or alignment constraints.
 ///
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 pub extern "C" fn __sys_malloc(size: usize, align: usize) -> *mut u8 {
 	let layout_res = Layout::from_size_align(size, align);
 	if layout_res.is_err() || size == 0 {
 		warn!(
-			"__sys_malloc called with size 0x{:x}, align 0x{:x} is an invalid layout!",
+			"__sys_malloc called with size {:#x}, align {:#x} is an invalid layout!",
 			size, align
 		);
 		return core::ptr::null::<*mut u8>() as *mut u8;
@@ -157,7 +159,7 @@ pub extern "C" fn __sys_malloc(size: usize, align: usize) -> *mut u8 {
 	let ptr = unsafe { ALLOCATOR.alloc(layout) };
 
 	trace!(
-		"__sys_malloc: allocate memory at 0x{:x} (size 0x{:x}, align 0x{:x})",
+		"__sys_malloc: allocate memory at {:#x} (size {:#x}, align {:#x})",
 		ptr as usize,
 		size,
 		align
@@ -185,7 +187,7 @@ pub extern "C" fn __sys_malloc(size: usize, align: usize) -> *mut u8 {
 /// # Errors
 /// Returns null if the new layout does not meet the size and alignment constraints of the
 /// allocator, or if reallocation otherwise fails.
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 pub extern "C" fn __sys_realloc(
 	ptr: *mut u8,
 	size: usize,
@@ -196,7 +198,7 @@ pub extern "C" fn __sys_realloc(
 		let layout_res = Layout::from_size_align(size, align);
 		if layout_res.is_err() || size == 0 || new_size == 0 {
 			warn!(
-			"__sys_realloc called with ptr 0x{:x}, size 0x{:x}, align 0x{:x}, new_size 0x{:x} is an invalid layout!",
+			"__sys_realloc called with ptr {:#x}, size {:#x}, align {:#x}, new_size {:#x} is an invalid layout!",
 			ptr as usize, size, align, new_size
 		);
 			return core::ptr::null::<*mut u8>() as *mut u8;
@@ -206,12 +208,12 @@ pub extern "C" fn __sys_realloc(
 
 		if new_ptr.is_null() {
 			debug!(
-			"__sys_realloc failed to resize ptr 0x{:x} with size 0x{:x}, align 0x{:x}, new_size 0x{:x} !",
+			"__sys_realloc failed to resize ptr {:#x} with size {:#x}, align {:#x}, new_size {:#x} !",
 			ptr as usize, size, align, new_size
 		);
 		} else {
 			trace!(
-				"__sys_realloc: resized memory at 0x{:x}, new address 0x{:x}",
+				"__sys_realloc: resized memory at {:#x}, new address {:#x}",
 				ptr as usize,
 				new_ptr as usize
 			);
@@ -230,20 +232,20 @@ pub extern "C" fn __sys_realloc(
 ///
 /// # Errors
 /// May panic if debug assertions are enabled and invalid parameters `size` or `align` where passed.
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 pub extern "C" fn __sys_free(ptr: *mut u8, size: usize, align: usize) {
 	unsafe {
 		let layout_res = Layout::from_size_align(size, align);
 		if layout_res.is_err() || size == 0 {
 			warn!(
-				"__sys_free called with size 0x{:x}, align 0x{:x} is an invalid layout!",
+				"__sys_free called with size {:#x}, align {:#x} is an invalid layout!",
 				size, align
 			);
 			debug_assert!(layout_res.is_err(), "__sys_free error: Invalid layout");
 			debug_assert_ne!(size, 0, "__sys_free error: size cannot be 0");
 		} else {
 			trace!(
-				"sys_free: deallocate memory at 0x{:x} (size 0x{:x})",
+				"sys_free: deallocate memory at {:#x} (size {:#x})",
 				ptr as usize,
 				size
 			);
@@ -253,7 +255,7 @@ pub extern "C" fn __sys_free(ptr: *mut u8, size: usize, align: usize) {
 	}
 }
 
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 extern "C" {
 	static mut __bss_start: usize;
 }
@@ -265,7 +267,7 @@ fn has_ipdevice() -> bool {
 }
 
 /// Entry point of a kernel thread, which initialize the libos
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 extern "C" fn initd(_arg: usize) {
 	extern "C" {
 		#[cfg(not(test))]
@@ -292,9 +294,8 @@ extern "C" fn initd(_arg: usize) {
 		info!("HermitCore is running on common system!");
 	}
 
-	// Initialize PCI Drivers if on x86_64
-	#[cfg(all(target_arch = "x86_64", feature = "pci"))]
-	x86_64::kernel::pci::init_drivers();
+	// Initialize Drivers
+	arch::init_drivers();
 
 	syscalls::init();
 
@@ -326,19 +327,19 @@ fn synch_all_cores() {
 }
 
 /// Entry Point of HermitCore for the Boot Processor
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 fn boot_processor_main() -> ! {
 	// Initialize the kernel and hardware.
 	arch::message_output_init();
 	logging::init();
 
 	info!("Welcome to HermitCore-rs {}", env!("CARGO_PKG_VERSION"));
-	info!("Kernel starts at 0x{:x}", environment::get_base_address());
-	info!("BSS starts at 0x{:x}", unsafe {
+	info!("Kernel starts at {:#x}", environment::get_base_address());
+	info!("BSS starts at {:#x}", unsafe {
 		&__bss_start as *const usize as usize
 	});
 	info!(
-		"TLS starts at 0x{:x} (size {} Bytes)",
+		"TLS starts at {:#x} (size {} Bytes)",
 		environment::get_tls_start(),
 		environment::get_tls_memsz()
 	);
@@ -379,7 +380,7 @@ fn boot_processor_main() -> ! {
 }
 
 /// Entry Point of HermitCore for an Application Processor
-#[cfg(all(target_os = "hermit", feature = "smp"))]
+#[cfg(all(any(target_os = "none", target_os = "hermit"), feature = "smp"))]
 fn application_processor_main() -> ! {
 	arch::application_processor_init();
 	scheduler::add_current_core();
