@@ -1,10 +1,3 @@
-// Copyright (c) 2017 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 use alloc::collections::linked_list::LinkedList;
 use core::{alloc::AllocError, cmp::Ordering};
 
@@ -88,6 +81,38 @@ impl FreeList {
 		Err(AllocError)
 	}
 
+	pub fn reserve(&mut self, address: usize, size: usize) -> Result<(), AllocError> {
+		trace!(
+			"Try to reserve {} bytes at {:#X} from Free List {:#X}",
+			size,
+			address,
+			self as *const Self as usize
+		);
+
+		// Find a region in the Free List that has at least the requested size.
+		let mut cursor = self.list.cursor_front_mut();
+		while let Some(node) = cursor.current() {
+			let (region_start, region_size) = (node.start, node.end - node.start);
+
+			if address > region_start && address + size < region_start + region_size {
+				node.start = address + size;
+				let new_entry = FreeListEntry::new(region_start, address);
+				cursor.insert_before(new_entry);
+				return Ok(());
+			} else if address > region_start && address + size == region_start + region_size {
+				node.start = address + size;
+				return Ok(());
+			} else if address == region_start && address + size < region_start + region_size {
+				node.start = region_start + size;
+				return Ok(());
+			}
+
+			cursor.move_next();
+		}
+
+		Err(AllocError)
+	}
+
 	pub fn deallocate(&mut self, address: usize, size: usize) {
 		trace!(
 			"Deallocating {} bytes at {:#X} from Free List {:#X}",
@@ -165,7 +190,7 @@ impl FreeList {
 	}
 }
 
-#[cfg(not(target_os = "hermit"))]
+#[cfg(not(any(target_os = "none", target_os = "hermit")))]
 #[test]
 fn add_element() {
 	let mut freelist = FreeList::new();
@@ -183,7 +208,7 @@ fn add_element() {
 	}
 }
 
-#[cfg(not(target_os = "hermit"))]
+#[cfg(not(any(target_os = "none", target_os = "hermit")))]
 #[test]
 fn allocate() {
 	let mut freelist = FreeList::new();
@@ -216,7 +241,7 @@ fn allocate() {
 	}
 }
 
-#[cfg(not(target_os = "hermit"))]
+#[cfg(not(any(target_os = "none", target_os = "hermit")))]
 #[test]
 fn deallocate() {
 	let mut freelist = FreeList::new();
