@@ -1,11 +1,3 @@
-// Copyright (c) 2017 Stefan Lankes, RWTH Aachen University
-//               2018 Colin Finck, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 use crate::arch;
 use crate::arch::mm::VirtAddr;
 use crate::arch::percore::*;
@@ -15,7 +7,6 @@ use alloc::collections::{LinkedList, VecDeque};
 use alloc::rc::Rc;
 use core::cell::RefCell;
 use core::cmp::Ordering;
-use core::convert::TryInto;
 use core::fmt;
 use core::num::NonZeroU64;
 
@@ -229,6 +220,7 @@ impl TaskHandlePriorityQueue {
 	}
 }
 
+#[derive(Default)]
 struct QueueHead {
 	head: Option<Rc<RefCell<Task>>>,
 	tail: Option<Rc<RefCell<Task>>>,
@@ -243,15 +235,6 @@ impl QueueHead {
 	}
 }
 
-impl Default for QueueHead {
-	fn default() -> Self {
-		Self {
-			head: None,
-			tail: None,
-		}
-	}
-}
-
 /// Realize a priority queue for tasks
 pub struct PriorityTaskQueue {
 	queues: [QueueHead; NO_PRIORITIES],
