@@ -1,12 +1,4 @@
-// Copyright (c) 2018 Stefan Lankes, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
-use alloc::prelude::v1::Box;
-use alloc::vec::Vec;
+use alloc::{boxed::Box, vec::Vec};
 use core::mem;
 
 #[cfg(target_arch = "x86_64")]
@@ -215,7 +207,7 @@ impl SyscallInterface for Uhyve {
 	///
 	/// ToDo: Add Safety section under which circumctances this is safe/unsafe to use
 	/// ToDo: Add an Errors section - What happens when e.g. malloc fails, how is that handled (currently it isn't)
-	#[cfg(target_os = "hermit")]
+	#[cfg(any(target_os = "none", target_os = "hermit"))]
 	fn get_application_parameters(&self) -> (i32, *const *const u8, *const *const u8) {
 		// determine the number of arguments and environment variables
 		let mut syscmdsize = SysCmdsize::new();
