@@ -1,20 +1,12 @@
-// Copyright (c) 2018 Colin Finck, RWTH Aachen University
-//                    Stefan Lankes, RWTH Aachen University
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-
 #![allow(clippy::result_unit_err)]
 
-#[cfg(all(not(feature = "newlib"), feature = "pci", target_arch = "x86_64"))]
+#[cfg(all(not(feature = "newlib"), target_arch = "x86_64"))]
 use crate::drivers::net::*;
 use crate::environment;
 #[cfg(feature = "newlib")]
 use crate::synch::spinlock::SpinlockIrqSave;
 use crate::syscalls::interfaces::SyscallInterface;
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 use crate::{__sys_free, __sys_malloc, __sys_realloc};
 
 pub use self::condvar::*;
@@ -68,19 +60,19 @@ pub fn init() {
 	sbrk_init();
 }
 
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 #[no_mangle]
 pub extern "C" fn sys_malloc(size: usize, align: usize) -> *mut u8 {
 	__sys_malloc(size, align)
 }
 
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 #[no_mangle]
 pub extern "C" fn sys_realloc(ptr: *mut u8, size: usize, align: usize, new_size: usize) -> *mut u8 {
 	__sys_realloc(ptr, size, align, new_size)
 }
 
-#[cfg(target_os = "hermit")]
+#[cfg(any(target_os = "none", target_os = "hermit"))]
 #[no_mangle]
 pub extern "C" fn sys_free(ptr: *mut u8, size: usize, align: usize) {
 	__sys_free(ptr, size, align)
@@ -114,6 +106,16 @@ extern "C" fn __sys_get_tx_buffer(len: usize, ret: &mut Result<(*mut u8, usize),
 	*ret = unsafe { SYS.get_tx_buffer(len) };
 }
 
+#[allow(improper_ctypes_definitions)]
+extern "C" fn __sys_free_tx_buffer(handle: usize) -> Result<(), ()> {
+	unsafe { SYS.free_tx_buffer(handle) }
+}
+
+#[no_mangle]
+pub fn sys_free_tx_buffer(handle: usize) -> Result<(), ()> {
+	kernel_function!(__sys_free_tx_buffer(handle))
+}
+
 #[no_mangle]
 pub fn sys_get_tx_buffer(len: usize) -> Result<(*mut u8, usize), ()> {
 	let mut ret = Err(());
@@ -152,13 +154,13 @@ pub fn sys_rx_buffer_consumed(handle: usize) -> Result<(), ()> {
 	kernel_function!(__sys_rx_buffer_consumed(handle))
 }
 
-#[cfg(all(not(feature = "newlib"), feature = "pci", target_arch = "x86_64"))]
+#[cfg(all(not(feature = "newlib"), target_arch = "x86_64"))]
 #[no_mangle]
 pub extern "C" fn sys_netwait() {
 	kernel_function!(netwait());
 }
 
-#[cfg(all(not(feature = "newlib"), feature = "pci", target_arch = "x86_64"))]
+#[cfg(all(not(feature = "newlib"), target_arch = "x86_64"))]
 #[no_mangle]
 pub extern "C" fn sys_set_network_polling_mode(value: bool) {
 	kernel_function!(set_polling_mode(value));
