@@ -13,7 +13,7 @@ mod common;
 /// - kernel boot-time
 /// - overhead of runtime_entry (test entry)
 #[no_mangle]
-pub fn main(args: Vec<String>) -> Result<(), ()> {
+pub fn main(_args: Vec<String>) -> Result<(), ()> {
 	Ok(())
 }
 
