@@ -1,4 +1,5 @@
 #![feature(test)]
+#![feature(thread_local)]
 #![no_std]
 #![no_main]
 #![test_runner(common::test_case_runner)]
@@ -40,6 +41,32 @@ pub fn thread_test() {
 	}
 }
 
+#[test_case]
+pub fn test_thread_local() {
+	#[repr(C, align(0x1000))]
+	struct AlignedByte(u8);
+
+	#[thread_local]
+	static mut BYTE: u8 = 0x42;
+
+	#[thread_local]
+	static mut CAFECAFE: u64 = 0xCAFECAFE;
+
+	#[thread_local]
+	static mut DEADBEEF: u64 = 0xDEADBEEF;
+
+	#[thread_local]
+	static mut ALIGNED_BYTE: AlignedByte = AlignedByte(0x53);
+
+	// If the thread local statics are not mut, they get optimized away in release.
+	unsafe {
+		assert_eq!(0x42, BYTE);
+		assert_eq!(0xCAFECAFE, CAFECAFE);
+		assert_eq!(0xDEADBEEF, DEADBEEF);
+		assert_eq!(0x53, ALIGNED_BYTE.0);
+	}
+}
+
 #[no_mangle]
 extern "C" fn runtime_entry(_argc: i32, _argv: *const *const u8, _env: *const *const u8) -> ! {
 	test_main();
